==> 3.6.8.zip: source-immo/views/list/listings/direct/item-raw.php <==
<?php
$classes = array();

if(isset($item->open_houses) && count($item->open_houses)>0){
    $classes[] = 'has-open-house';
}
if($item->status_code=='SOLD'){
    $classes[] = 'sold';
}

$classes = apply_filters('si/list-item/raw/classes', $classes);

?>

<article class="si-item si-listing-item si-raw-item-layout <?php echo implode(' ',$classes) ?>"
    itemscope itemtype="http://schema.org/Residence">
    <a itemprop="url" href="<?php echo($item->permalink) ?>">
        <div class="si-item-content" itemprop="name" content="<?php echo($item->subcategory);?> <?php echo($item->transaction);?>">
            <div class="si-image si-lazy-loading"><img si-src="<?php echo(str_replace('-sm.', '-lg.', $item->photo_url));?>" si-srcset="<?php echo(apply_filters('si_listing_srcset',$item->photo_url))?>" itemprop="image" /></div>
            <div class="si-data-label si-civic-address" itemscope itemtype="http://schema.org/PostalAddress" itemprop="address"><span itemprop="streetAddress"><?php echo($item->location->civic_address);?></span></div>
            <div class="si-data-label si-city" itemscope itemtype="http://schema.org/PostalAddress" itemprop="address"><span itemprop="addressLocality"><?php echo($item->location->city);?></span></div>
            <div class="si-data-label si-region"><?php echo($item->location->region);?></div>

            <div class="si-data-label si-price"><?php echo($item->price_text);?></div>
            
            <div class="si-data-label si-category"><?php echo($item->category);?></div>
            <div class="si-data-label si-subcategory"><?php echo($item->subcategory);?></div>
            
            <div class="si-data-label si-ref-number" ><?php echo($item->ref_number);?></div>
            
            <div class="si-data-label si-available_area"><?php echo($item->available_area)?> <?php echo($item->available_area_unit) ?></div>
            <?php

            if(isset($item->counters->rooms)){?>
            <div class="si-data-label si-rooms">
                <?php 
                    foreach ($item->counters->rooms as $icon => $room) {
                        echo('<div class="si-room ' . $icon . '"><i class="icon fal fa-fw fa-' . $icon . '"></i> <span class="si-count">' . $room->count . '</span> <span class="si-label">' . $room->label . '</span></div>');
                    }
                ?>
            </div>
            <?php } ?>

            <div class="si-data-label si-description" itemprop="description"><?php echo(isset($item->description) ? $item->description : '');?></div>
            
	        <div class="si-open-houses">
                <?php if(isset($item->open_houses) && count($item->open_houses)>0){ ?>
            	<div class="si-open-house-item">
                    <si-icon>calendar-alt</si-icon> <?php si_label('Open house') ?> <span><?php echo(Moment::time_ago($item->open_houses[0]->start_date)) ?></span>
            	</div>
                <?php } ?>
	        </div>

            <div class="si-item-link-button">
                <?php
                si_button( _si_label("Learn more") );
                ?>
            </div>
        </div>
        
    </a>
</article>

==> 3.7.5.zip: source-immo/views/list/listings/direct/item-raw.php <==
<?php
$classes = array();

if(isset($item->open_houses) && count($item->open_houses)>0){
    $classes[] = 'has-open-house';
}
if($item->status_code=='SOLD'){
    $classes[] = 'sold';
}

$classes = apply_filters('si/list-item/raw/classes', $classes);

?>

<article class="si-item si-listing-item si-raw-item-layout <?php echo implode(' ',$classes) ?>"
    itemscope itemtype="http://schema.org/Residence">
    <a itemprop="url" href="<?php echo($item->permalink) ?>">
        <div class="si-item-content" itemprop="name" content="<?php echo($item->subcategory);?> <?php echo($item->transaction);?>">
            <div class="si-image si-lazy-loading"><img si-src="<?php echo(str_replace('-sm.', '-lg.', $item->photo_url));?>" itemprop="image" /></div>
            <div class="si-data-label si-civic-address" itemscope itemtype="http://schema.org/PostalAddress" itemprop="address"><span itemprop="streetAddress"><?php echo($item->location->civic_address);?></span></div>
            <div class="si-data-label si-city" itemscope itemtype="http://schema.org/PostalAddress" itemprop="address"><span itemprop="addressLocality"><?php echo($item->location->city);?></span></div>
            <div class="si-data-label si-region"><?php echo($item->location->region);?></div>

            <div class="si-data-label si-price"><?php echo($item->price_text);?></div>
            
            <div class="si-data-label si-category"><?php echo($item->category);?></div>
            <div class="si-data-label si-subcategory"><?php echo($item->subcategory);?></div>
            
            <div class="si-data-label si-ref-number" ><?php echo($item->ref_number);?></div>
            
            <div class="si-data-label si-available_area"><?php echo($item->available_area)?> <?php echo($item->available_area_unit) ?></div>
            <?php

            if(isset($item->counters->rooms)){?>
            <div class="si-data-label si-rooms">
                <?php 
                    foreach ($item->counters->rooms as $icon => $room) {
                        echo('<div class="si-room ' . $icon . '"><i class="icon fal fa-fw fa-' . $icon . '"></i> <span class="si-count">' . $room->count . '</span> <span class="si-label">' . $room->label . '</span></div>');
                    }
                ?>
            </div>
            <?php } ?>

            <div class="si-data-label si-description" itemprop="description"><?php echo(isset($item->description) ? $item->description : '');?></div>
            
	        <div class="si-open-houses">
                <?php if(isset($item->open_houses) && count($item->open_houses)>0){ ?>
            	<div class="si-open-house-item">
                    <si-icon>calendar-alt</si-icon> <?php si_label('Open house') ?> <span><?php echo(Moment::time_ago($item->open_houses[0]->start_date)) ?></span>
            	</div>
                <?php } ?>
	        </div>

            <div class="si-item-link-button">
                <?php
                si_button( _si_label("Learn more") );
                ?>
            </div>
        </div>
        
    </a>
</article>
